<?php

namespace Drupal\ipless\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * IpLessSettingForm is an helper class used in form alter hook.
 *
 * @see ipless_form_alter().
 */
class IpLessSettingForm {

  use StringTranslationTrait;

  /**
   * Form Callback : Check settings.
   *
   * @param array $form
   *   The form array.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state object.
   */
  public static function checkSettings(array &$form, FormStateInterface $form_state) {
    $config = \Drupal::service('config.factory')
      ->getEditable('system.performance');

    $form_state->cleanValues();
    $config->set('ipless', $form_state->getValue('ipless'));
    $config->save();
  }

  /**
   * Form Alter.
   *
   * @param array $form
   *   The form element.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state object.
   */
  public function formAlterSystemPerformanceSettings(&$form, FormStateInterface $form_state) {
    $config = \Drupal::config('system.performance');

    $form['bandwidth_optimization']['ipless'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Less CSS'),
      '#tree' => TRUE,
    ];

    $form['bandwidth_optimization']['ipless']['enabled'] = [
      '#type' => 'checkbox',
      '#default_value' => $config->get('ipless.enabled'),
      '#title' => $this->t('Less compilation enabled'),
    ];

    $form['bandwidth_optimization']['ipless']['modedev'] = [
      '#type' => 'checkbox',
      '#default_value' => $config->get('ipless.modedev'),
      '#title' => $this->t('Less developper mode'),
      '#description' => $this->t('Compile Less file all the time.'),
    ];

    $form['bandwidth_optimization']['ipless']['sourcemap'] = [
      '#type' => 'checkbox',
      '#default_value' => $config->get('ipless.sourcemap'),
      '#title' => $this->t('Enable SourceMap'),
      '#states' => [
        'enabled' => [
          ':input[name="ipless[modedev]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $form['bandwidth_optimization']['ipless']['watch_mode'] = [
      '#type' => 'checkbox',
      '#default_value' => $config->get('ipless.watch_mode'),
      '#title' => $this->t('Enable watch mode'),
      '#description' => $this->t('Refreshed CSS sheets without needing to reload the page.'),
      '#states' => [
        'enabled' => [
          ':input[name="ipless[modedev]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $form['#submit'][] = static::class . '::checkSettings';
  }

}
